# services

Contains 2 binaries:

* `services` to display and add new services using a Web interface
* `updater` to update existing services uptime and metadata

## Dependencies

[Rocket](https://rocket.rs/)
: Web framework

[Tera](https://keats.github.io/tera/)
: HTML template

[Fluent](https://projectfluent.org/)
: translations

[Diesel](https://diesel.rs/)
: ORM for SQLite

[texting_robots](https://docs.rs/texting_robots/)
: robots.txt parser

[reqwest](https://docs.rs/reqwest/)
: HTTP requests

[asn-db2](https://docs.rs/asn-db2/)
: parse [IPtoASN](https://iptoasn.com/) tsv format

[kdl-rs](https://docs.rs/kdl-rs/)
: parse [KDL](https://kdl.dev/) configuration

## Installation

### Tooling

Install Rust and Cargo. If your distribution doesn't ship with recent enough versions, you can get them with [Rustup](https://rustup.rs/).

Install [Diesel CLI](https://diesel.rs/guides/getting-started#installing-diesel-cli). If your distribution doesn't ship it, you can install it using:
```shell
cargo install diesel_cli --no-default-features --features sqlite
```

### Data setup

Create SQLite database:
```shell
diesel database setup --database-url services.db
```

Download and decompress the combined [IPtoASN](https://iptoasn.com/) TSV file:
```shell
curl https://iptoasn.com/data/ip2asn-combined.tsv.gz | zcat > ip2asn-combined.tsv
```

### For development

```shell
cargo run --bin services
cargo run --bin updater
```

### For real use

Download dependencies:
```shell
cargo fetch --locked
```

Build (delete `` for a development build):
```shell
cargo build --frozen --release
```

* `target/release/services` should be HTTP reverse-proxied
* `target/release/updater` should be run periodically using a cron

## License

You can use, redistribute or modify under the terms of the CNPL-NAv7+ as found in [`LICENSE.md`](LICENSE.md) or at <https://git.pixie.town/thufie/npl-builder>.
