pub mod models;
pub mod schema;

use core::fmt::{Debug, Display, Formatter, Result};
use std::fs::read_to_string;

use kdl::KdlDocument;

pub struct Config {
	pub database: String,
	pub ip_to_asn: String,
	pub source_code: String,
}
fn get_config_arg(kdl: &KdlDocument, key: &str) -> String {
	kdl.get_arg(key)
		.unwrap_or_else(|| panic!("config: missing {key}"))
		.as_string()
		.unwrap_or_else(|| panic!("config: {key} must be a string"))
		.to_owned()
}
pub fn get_config() -> Config {
	let kdl: KdlDocument = read_to_string("config.kdl")
		.expect("unable to open config.kdl")
		.parse()
		.expect("failed to parse KDL");
	Config {
		database: get_config_arg(&kdl, "database"),
		ip_to_asn: get_config_arg(&kdl, "ip-to-asn"),
		source_code: get_config_arg(&kdl, "source-code"),
	}
}

#[derive(rocket::FromFormField, Debug, PartialEq)]
pub enum Software {
	PeerTube,
	Etherpad,
	Invidious,
	LibreQR,
	ServNest,
	Lufi,
	Librex,
	Forgejo,
	Gitea,
}
impl Display for Software {
	fn fmt(&self, f: &mut Formatter) -> Result {
		Debug::fmt(self, f)
	}
}
